@@ -1,5 +1,5 @@
 import os
-
+import shutil
 def create_project():
     current_directory = os.getcwd()
     folders_to_create = ['config', 'data', 'docs', 'models', 'notebooks', 'utils']
@@ -22,4 +22,10 @@ def create_project():
     with open(os.path.join(current_directory, 'requirements.txt'), 'w') as reqfile:
         reqfile.writelines(['django'])
 
-create_project()
+if 1>0:
+    print("Creating Project Folders!!!!")
+    create_project()
+    current_directory = os.getcwd()
+    shutil.copyfile(r'test_environment.py', os.path.join(current_directory, 'test_environment.py'))
+else:
+    print("Something went worng!!!!")
\ No newline at end of file
